fedex.printers

Package fedex :: Package printers |
[hide private]
[frames] | no frames]

# Package printers

source code

Optional classes used for the convenient printing of FedEx labels from FedexProcessShipmentRequest objects. Each printer class is more or less the same, following the pattern seen below (unless otherwise documented).:

       from fedex.printers.unix import DirectDevicePrinter
       # Where shipment is an existing L{FedexProcessShipmentRequest} object.
       shipment.send_request()
       device = DirectDevicePrinter(shipment)
       device.print_label()

Submodules | [hide private]
fedex.printers.unix: This module provides a label printing wrapper class for Unix-based installations.

Variables | [hide private]
| __package__ = `None`